CollectionLoader
================

.. currentmodule:: toasty.collection

.. autoclass:: CollectionLoader
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~CollectionLoader.blankval
      ~CollectionLoader.hdu_index

   .. rubric:: Methods Summary

   .. autosummary::

      ~CollectionLoader.add_arguments
      ~CollectionLoader.create_from_args
      ~CollectionLoader.load_paths

   .. rubric:: Attributes Documentation

   .. autoattribute:: blankval
   .. autoattribute:: hdu_index

   .. rubric:: Methods Documentation

   .. automethod:: add_arguments
   .. automethod:: create_from_args
   .. automethod:: load_paths
